@@ -484,6 +484,8 @@ CHIPSET(0x67B8, HAWAII_67B8, HAWAII)
 CHIPSET(0x67B9, HAWAII_67B9, HAWAII)
 CHIPSET(0x67BA, HAWAII_67BA, HAWAII)
 CHIPSET(0x67BE, HAWAII_67BE, HAWAII)
+
+
 CHIPSET(0x6900, 0x6900, TOPAZ)
 CHIPSET(0x6901, 0x6901, TOPAZ)
 CHIPSET(0x6902, 0x6902, TOPAZ)
@@ -499,13 +501,13 @@ CHIPSET(0x6930, 0x6930, TONGA)
 CHIPSET(0x6938, 0x6938, TONGA)
 CHIPSET(0x6939, 0x6939, TONGA)
 CHIPSET(0x7300, 0x7300, FIJI)
+CHIPSET(0x730F, 0x730F, FIJI)
 CHIPSET(0x9870, 0x9870, CARRIZO)
 CHIPSET(0x9874, 0x9874, CARRIZO)
 CHIPSET(0x9875, 0x9875, CARRIZO)
 CHIPSET(0x9876, 0x9876, CARRIZO)
 CHIPSET(0x9877, 0x9877, CARRIZO)
 CHIPSET(0x98E4, 0x98E4, STONEY)
-
 CHIPSET(0x67E0, 0x67E0, POLARIS11)
 CHIPSET(0x67E3, 0x67E3, POLARIS11)
 CHIPSET(0x67E8, 0x67E8, POLARIS11)
@@ -515,15 +517,33 @@ CHIPSET(0x67FF, 0x67FF, POLARIS11)
 CHIPSET(0x67E1, 0x67E1, POLARIS11)
 CHIPSET(0x67E7, 0x67E7, POLARIS11)
 CHIPSET(0x67E9, 0x67E9, POLARIS11)
-
 CHIPSET(0x67C0, 0x67C0, POLARIS10)
 CHIPSET(0x67C1, 0x67C1, POLARIS10)
 CHIPSET(0x67C2, 0x67C2, POLARIS10)
 CHIPSET(0x67C4, 0x67C4, POLARIS10)
 CHIPSET(0x67C7, 0x67C7, POLARIS10)
+CHIPSET(0x67D0, 0x67D0, POLARIS10)
 CHIPSET(0x67DF, 0x67DF, POLARIS10)
 CHIPSET(0x67C8, 0x67C8, POLARIS10)
 CHIPSET(0x67C9, 0x67C9, POLARIS10)
 CHIPSET(0x67CA, 0x67CA, POLARIS10)
 CHIPSET(0x67CC, 0x67CC, POLARIS10)
 CHIPSET(0x67CF, 0x67CF, POLARIS10)
+CHIPSET(0x6980, 0x6980, POLARIS12)
+CHIPSET(0x6981, 0x6981, POLARIS12)
+CHIPSET(0x6985, 0x6985, POLARIS12)
+CHIPSET(0x6986, 0x6986, POLARIS12)
+CHIPSET(0x6987, 0x6987, POLARIS12)
+CHIPSET(0x6995, 0x6995, POLARIS12)
+CHIPSET(0x6997, 0x6997, POLARIS12)
+CHIPSET(0x699F, 0x699F, POLARIS12)
+CHIPSET(0x6860, 0x6860, VEGA10)
+CHIPSET(0x6861, 0x6861, VEGA10)
+CHIPSET(0x6862, 0x6862, VEGA10)
+CHIPSET(0x6863, 0x6863, VEGA10)
+CHIPSET(0x6864, 0x6864, VEGA10)
+CHIPSET(0x6867, 0x6867, VEGA10)
+CHIPSET(0x6868, 0x6868, VEGA10)
+CHIPSET(0x686c, 0x686c, VEGA10)
+CHIPSET(0x687f, 0x687f, VEGA10)
+CHIPSET(0x15dd, 0x15dd, RAVEN)
