@@ -47,16 +47,16 @@ static void help(const char * const me, const unsigned int ticks) {
 }
 
 int get_drm_value(int fd, unsigned request, uint32_t *out) {
-    struct drm_radeon_info info;
-    int retval;
+	struct drm_radeon_info info;
+	int retval;
 
-    memset(&info, 0, sizeof(info));
+	memset(&info, 0, sizeof(info));
 
-    info.value = (unsigned long)out;
-    info.request = request;
+	info.value = (unsigned long)out;
+	info.request = request;
 
-    retval = drmCommandWriteRead(fd, DRM_RADEON_INFO, &info, sizeof(info));
-    return !retval;
+	retval = drmCommandWriteRead(fd, DRM_RADEON_INFO, &info, sizeof(info));
+	return !retval;
 }
 
 unsigned int readgrbm() {
@@ -73,6 +73,8 @@ unsigned int readgrbm() {
 }
 
 int main(int argc, char **argv) {
+	// Temporarily drop privileges to do option parsing, etc.
+	seteuid(getuid());
 
 	unsigned int ticks = 120;
 	unsigned char color = 0;
@@ -133,8 +135,10 @@ int main(int argc, char **argv) {
 		}
 	}
 
-	// init
+	// init (regain privileges for bus initialization and ultimately drop them afterwards)
+	seteuid(0);
 	const unsigned int pciaddr = init_pci(bus, forcemem);
+	setuid(getuid());
 
 	const int family = getfamily(pciaddr);
 	if (!family)
